PCB Environment: UniformGrid25 Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields | Protected Member Functions | Protected Attributes
UniformGrid25 Class Reference
Inheritance diagram for UniformGrid25:

## Public Member Functions
| UniformGrid25 (Real edgeLen)
IVector_3 | getSize () const
uint | getSize (uint d) const
const Bbox_2 & | getBbox () const
Real | XCoord (int x) const
Real | YCoord (int y) const
Point_2 | Coords (const IPoint_2 &v) const
Point_2 | Coords (int x, int y) const
Point_25 | Coords (const IPoint_3 &v) const
Point_25 | Coords (int x, int y, uint z) const
Vector_2 | MidPointOffset () const
Real | MidPointX (int x) const
Real | MidPointY (int y) const
Point_2 | MidPoint (const IPoint_2 &v) const
Point_2 | MidPoint (int x, int y) const
Point_25 | MidPoint (const IPoint_3 &v) const
IVector_2 | HIndices (const Point_2 &v) const
int | XIndex (Real x, Real ex=0.0) const
int | YIndex (Real y, Real ey=0.0) const
uint | XIndexBounded (Real x, Real ex=0.0) const
uint | YIndexBounded (Real y, Real ey=0.0) const
uint | LinearIndex (uint z, uint y, uint x) const
uint | LinearIndex (const Point_25 &v) const
IBox_3 | getBox (const Bbox_2 &, uint z0=0, uint z1=std::numeric_limits< uint >::max()) const
Real | XfIndex (Real x, Real ex=0.0) const
Real | YfIndex (Real y, Real ey=0.0) const
uint | getNumPoints2D () const
uint | getNumPoints3D () const
bool | inside (const IPoint_3 &v) const
bool | inside (uint x, uint y, uint z) const
Point_25 | snapToMidPoint (const Point_25 &) const

## Data Fields
const Real | EdgeLen
const Real | EdgeLen05
const Real | EdgeLenRcp

## Protected Member Functions
void | calcNumPoints3D ()

## Protected Attributes
Bbox_2 | mBbox
uint | mSize [3]
uint | mStrideZ
uint | mStrideY
uint | mNumPoints3D

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UniformGrid25.hpp